.. image:: https://img.shields.io/badge/python-3-blue.svg
   :target: https://www.python.org/
   :alt: Python 3

.. image:: https://api.codeclimate.com/v1/badges/616db0cff952ea5c8a6a/maintainability
   :target: https://codeclimate.com/github/edukorg/glassfrog-py/maintainability
   :alt: Maintainability

.. image:: https://api.codeclimate.com/v1/badges/616db0cff952ea5c8a6a/test_coverage
   :target: https://codeclimate.com/github/edukorg/glassfrog-py/test_coverage
   :alt: Test Coverage


glassfrog-py
